#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 system-fileio
version:              0.3.16.4
visibility:           public
id:                   system-fileio-0.3.16.4-LZpoEULtGko2yGSsaGrZPB
key:                  system-fileio-0.3.16.4-LZpoEULtGko2yGSsaGrZPB
license:              MIT
maintainer:           FP Complete <michael@fpcomplete.com>
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://github.com/fpco/haskell-filesystem
synopsis:
    Consistent filesystem interaction across GHC versions (deprecated)

description:
    Please see: https://plus.google.com/+MichaelSnoyman/posts/Ft5hnPqpgEx

category:             System
abi:                  e8e8ee2b1bdb7e5a951c34fb894f838b
exposed:              True
exposed-modules:      Filesystem
import-dirs:          /usr/lib/ghc-8.10.5/site-local/system-fileio-0.3.16.4
library-dirs:         /usr/lib/ghc-8.10.5/site-local/system-fileio-0.3.16.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/system-fileio-0.3.16.4
hs-libraries:         HSsystem-fileio-0.3.16.4-LZpoEULtGko2yGSsaGrZPB
depends:
    base-4.14.2.0 bytestring-0.10.12.0
    system-filepath-0.4.14-4xdghdB8j5JLausoS7zTGm text-1.2.4.1
    time-1.9.3 unix-2.7.2.2

haddock-interfaces:
    /usr/share/doc/haskell-system-fileio/html/system-fileio.haddock

haddock-html:         /usr/share/doc/haskell-system-fileio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

